=====
django-tool
=====

djtool is a simple Django app to conduct Web-based tool. For each
question, visitors can choose between a fixed number of answers.

Detailed documentation is in the "docs" directory.

Quick start
-----------

Add "djtool" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = (
        ...
        'djtool',
    )